@@ -1,7 +1,7 @@
 /*
  * Functions and variables common to all programs in the project.
  *
- * Copyright 2014, 2021, 2023, 2025 Andrew Wood
+ * Copyright 2014, 2021, 2023, 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -144,7 +144,7 @@ void die(const char *format, ...)
  * Return the string position of the character just after the last '/' in
  * the given path.
  */
-size_t ds_leafname_pos( /*@null@ */ char *pathname)
+size_t ds_leafname_pos( /*@null@ */ const char *pathname)
 {
 	size_t leafpos;
 
@@ -186,7 +186,7 @@ size_t ds_leafname_pos( /*@null@ */ char *pathname)
  *
  * Returns -1 on error, in which case nothing is put into tmpnameptr.
  */
-int ds_tmpfile( /*@null@ */ char *pathname, /*@null@ */ nullable_string * tmpnameptr)
+int ds_tmpfile( /*@null@ */ const char *pathname, /*@null@ */ nullable_string *tmpnameptr)
 {
 	size_t leafpos;
 	int fd;
@@ -510,7 +510,7 @@ size_t calculateDisplayedWidth(const char *string)
  * This is a 7-bit ASCII version of outputWordWrap() below - it does not
  * understand multi-byte characters, so it would count those incorrectly.
  */
-static void nonWideOutputWordWrap(FILE * stream, const char *string, size_t wrapWidth, size_t leftMargin)
+static void nonWideOutputWordWrap(FILE *stream, const char *string, size_t wrapWidth, size_t leftMargin)
 {
 	const char *start;
 	const char *end;
@@ -577,7 +577,7 @@ static void nonWideOutputWordWrap(FILE * stream, const char *string, size_t wrap
  * Wide characters are handled if NLS is enabled, but if they can't be, this
  * falls back to the version above, which just counts bytes as characters.
  */
-void outputWordWrap(FILE * stream, const char *string, size_t wrapWidth, size_t leftMargin)
+void outputWordWrap(FILE *stream, const char *string, size_t wrapWidth, size_t leftMargin)
 {
 #if defined(ENABLE_NLS) && defined(HAVE_WCHAR_H)
 	size_t stringWidth;
@@ -720,7 +720,7 @@ void outputWordWrap(FILE * stream, const char *string, size_t wrapWidth, size_t
  * Fill in *columns and *rows with the size of the terminal associated with
  * "stream", if possible.  Returns true if values were read.
  */
-bool readTerminalSize(FILE * stream, /*@null@ */ size_t *columns, /*@null@ */ size_t *rows)
+bool readTerminalSize(FILE *stream, /*@null@ */ size_t *columns, /*@null@ */ size_t *rows)
 {
 #ifdef TIOCGWINSZ
 	struct winsize wsz;
@@ -749,7 +749,7 @@ bool readTerminalSize(FILE * stream, /*@null@ */ size_t *columns, /*@null@ */ si
 /*
  * Display parameter definitions, word wrapping them as appropriate.
  */
-void showParameterDefinitions(FILE * stream, size_t columns, struct parameterDefinition *parameterDefinitions)
+void showParameterDefinitions(FILE *stream, size_t columns, struct parameterDefinition *parameterDefinitions)
 {
 	unsigned int parameterIndex;
 	size_t widestParameterWidth = 0;
