@@ -1,7 +1,7 @@
 /*
  * Header for functions common to all programs.
  *
- * Copyright 2014, 2021, 2023, 2025 Andrew Wood
+ * Copyright 2014, 2021, 2023, 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -25,7 +25,7 @@
 #include <stdbool.h>
 #endif	/* _STDBOOL_H */
 
-#define COPYRIGHT_YEAR "2025"
+#define COPYRIGHT_YEAR "2026"
 #define COPYRIGHT_HOLDER "Andrew Wood"
 
 #define ENABLE_SETPROCTITLE 1
@@ -61,9 +61,9 @@ void _debug(const char *, const char *, int, const char *, ...);
 void error(const char *, ...);
 void die(const char *, ...);
 
-size_t ds_leafname_pos(/*@null@*/ char *pathname);
+size_t ds_leafname_pos(/*@null@*/ const char *pathname);
 /*@dependent@*/ /*@null@*/ char *ds_leafname(/*@null@*/ char *pathname);
-int ds_tmpfile(/*@null@*/ char *pathname, /*@null@*/ nullable_string *tmpnameptr);
+int ds_tmpfile(/*@null@*/ const char *pathname, /*@null@*/ nullable_string *tmpnameptr);
 
 
 #if ENABLE_SETPROCTITLE
