@@ -3,7 +3,7 @@
  * synchronisation sets, providing an interface to the continual
  * synchronisation function continual_sync in sync.c.
  *
- * Copyright 2014, 2021, 2023, 2025 Andrew Wood
+ * Copyright 2014, 2021, 2023, 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -77,7 +77,7 @@ static int find_config_section(const char *name)
  * string if necessary, returning nonzero on error (and reporting the
  * error).
  */
-static int expand_config_sequences(struct sync_set_s *cf, /*@null@ */ nullable_string * strptr, char *parameter)
+static int expand_config_sequences(struct sync_set_s *cf, /*@null@ */ nullable_string *strptr, char *parameter)
 {
 	size_t orig_string_len = 0;
 	size_t new_string_len = 0;
@@ -508,7 +508,11 @@ static int parse_config(const char *filename, int depth)
 				if (cwdfd >= 0) {
 					int rc;
 					rc = chdir(resolved_path);
-					debug("(cf) chdir: %s = %d", resolved_path, rc);
+					if (0 == rc) {
+						debug("(cf) chdir: %s = %s", resolved_path, "OK");
+					} else {
+						debug("(cf) chdir: %s = %d: %s", resolved_path, rc, strerror(errno));
+					}
 				}
 				free(resolved_path);
 			}
@@ -780,7 +784,7 @@ config_sections[cf_idx].X = NULL; \
 /*
  * Write a string to a file stream, escaping it as JSON.
  */
-static void write_json_string(FILE * fptr, /*@null@ */ const char *string)
+static void write_json_string(FILE *fptr, /*@null@ */ const char *string)
 {
 	if (NULL == fptr)
 		return;
