@@ -2,7 +2,7 @@
  * Continuously synchronise the contents of a source directory to a given
  * destination, reading the details from a configuration file.
  *
- * Copyright 2014, 2021, 2023, 2025 Andrew Wood
+ * Copyright 2014, 2021, 2023, 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -79,9 +79,16 @@ static void recursively_delete(const char *, int);
  */
 /*@dependent@ */ static char *dump_time(time_t t)
 {
-	static char tbuf[256];
+	static char tbuf[256];		 /* flawfinder: ignore */
 	struct tm *tm;
 
+	/*
+	 * flawfinder rationale: the buffer is large enough for the string,
+	 * writes are bounded using strftime()'s max buffer length
+	 * parameter, and it is initialised with \0 bytes to ensure the
+	 * string is terminated.
+	 */
+
 	memset(tbuf, 0, sizeof(tbuf));
 
 	if (0 == t) {
@@ -178,6 +185,11 @@ static void update_status_file(struct sync_set_s *cf, struct sync_status_s *st)
 	free(temp_filename);
 }
 
+/*@-mustfreefresh@ */
+/*
+ * splint and gettext() / _() don't get on - we turn off mustfreefresh
+ * because splint thinks each gettext call causes a memory leak.
+ */
 
 /*
  * Run a continual sync as defined by the given configuration.  Assumes that
@@ -263,7 +275,12 @@ void continual_sync(struct sync_set_s *cf, bool rsync_null_delimiter)
 		goto continual_sync_final_cleanup;
 	}
 
-	fptr = fopen(status.excludes_file, "w");
+	fptr = fopen(status.excludes_file, "w");	/* flawfinder: ignore */
+	/*
+	 * flawfinder warns about the path being redirected but the path is
+	 * under a temporary directory we just created so an attacker would
+	 * need to already be running under the same user ID.
+	 */
 	if (NULL == fptr) {
 		error("%s: %s: %s", status.excludes_file, "fopen", strerror(errno));
 		goto continual_sync_final_cleanup;
@@ -662,6 +679,7 @@ static void run_watcher(struct sync_set_s *cf, bool rsync_null_delimiter)
 	params.queue_run_interval = 2;
 	params.queue_run_max_seconds = 5;
 	params.changedpath_dump_interval = cf->partial_interval;
+	params.exchange_interval = 1;
 	params.max_dir_depth = cf->recursion_depth;
 	for (exclude_idx = 0; exclude_idx < cf->exclude_count; exclude_idx++) {
 		params.excludes[exclude_idx] = cf->excludes[exclude_idx];
@@ -742,7 +760,8 @@ static int run_rsync(const char *log_file, const char *section, const char *sour
 	if (0 == rsync_pid) {
 		int fd;
 		/* Child - run rsync */
-		fd = open(rsync_error_file, O_CREAT | O_WRONLY, 0600);
+		fd = open(rsync_error_file, O_CREAT | O_WRONLY, 0600);	/* flawfinder: ignore */
+		/* flawfinder - see below about rsync_error_file. */
 		if (fd >= 0) {
 			(void) dup2(fd, 2);
 			(void) close(fd);
@@ -804,11 +823,17 @@ static int run_rsync(const char *log_file, const char *section, const char *sour
 		size_t linebuf_size = 0;
 		FILE *err_fptr;
 
-		err_fptr = fopen(rsync_error_file, "r");
+		err_fptr = fopen(rsync_error_file, "r");	/* flawfinder: ignore */
 		if (NULL == err_fptr) {
 			error("%s: %s", rsync_error_file, strerror(errno));
 			return rc;
 		}
+		/*
+		 * flawfinder warns about the path being redirected but the
+		 * path is under a temporary directory we just created so an
+		 * attacker would need to already be running under the same
+		 * user ID.
+		 */
 
 		while (0 == feof(err_fptr)) {
 			ssize_t line_length = 0;
@@ -855,7 +880,11 @@ static void update_timestamp_file(struct sync_set_s *cf, /*@null@ */ const char
 	FILE *fptr;
 	if (NULL == file)
 		return;
-	fptr = fopen(file, "a");
+	fptr = fopen(file, "a");	    /* flawfinder: ignore */
+	/*
+	 * flawfinder - negligible risk associated with possible redirection
+	 * of "file" since only its timestamp is updated.
+	 */
 	if (NULL != fptr) {
 		(void) fclose(fptr);
 	} else {
@@ -1188,7 +1217,7 @@ static int sync_partial(struct sync_set_s *cf, struct sync_status_s *st, bool rs
 		if (0 != lockf(lockfd, F_ULOCK, 0)) {
 			error("%s: %s(%d): %s", cf->sync_lock, "lockf", lockfd, strerror(errno));
 		}
-		close(lockfd);
+		(void) close(lockfd);
 	}
 
 	remove(cf->transfer_list);
@@ -1213,20 +1242,28 @@ static void log_message( /*@null@ */ const char *file, const char *format, ...)
 	va_list ap;
 	time_t t;
 	struct tm *tm;
-	char tbuf[128];
+	char tbuf[128];			 /* flawfinder: ignore */
 	bool locked;
 
+	/*
+	 * flawfinder note: tbuf is only written to by strftime() which
+	 * takes its size, and we enforce string termination.
+	 */
+
 	time(&t);
 	tm = localtime(&t);
-	tbuf[0] = 0;
-	strftime(tbuf, sizeof(tbuf), "%Y-%m-%d %H:%M:%S", tm);
+	tbuf[0] = '\0';
+	if (0 == strftime(tbuf, sizeof(tbuf), "%Y-%m-%d %H:%M:%S", tm)) {
+		tbuf[0] = '\0';
+	}
+	tbuf[sizeof(tbuf) - 1] = '\0';	    /* enforce termination */
 
 #if ENABLE_DEBUGGING
 	va_start(ap, format);
 	if (debugging_enabled) {
-		fprintf(stderr, "[%s] (log) ", tbuf);
-		vfprintf(stderr, format, ap);
-		fprintf(stderr, "\n");
+		(void) fprintf(stderr, "[%s] (log) ", tbuf);
+		(void) vfprintf(stderr, format, ap);	/* flawfinder: ignore */
+		(void) fprintf(stderr, "\n");
 	}
 	va_end(ap);
 #endif				/* ENABLE_DEBUGGING */
@@ -1249,11 +1286,17 @@ static void log_message( /*@null@ */ const char *file, const char *format, ...)
 		locked = true;
 	fseek(fptr, 0, SEEK_END);
 
-	fprintf(fptr, "[%s] ", tbuf);
+	(void) fprintf(fptr, "[%s] ", tbuf);
 	va_start(ap, format);
-	vfprintf(fptr, format, ap);
+	(void) vfprintf(fptr, format, ap);  /* flawfinder: ignore */
 	va_end(ap);
-	fprintf(fptr, "\n");
+	(void) fprintf(fptr, "\n");
+
+	/*
+	 * flawfinder rationale: the format string for these vfprintf()
+	 * calls is provided by the caller, so it's up to the caller to make
+	 * sure it's safe.
+	 */
 
 	if (locked) {
 		if (0 == lockf(fileno(fptr), F_ULOCK, 0))
@@ -1273,7 +1316,12 @@ static void recursively_delete(const char *dir, int depth)
 {
 	struct dirent **namelist;
 	int namelist_length, idx;
-	char path[4096] = { 0, };
+	char path[4096];		 /* flawfinder: ignore */
+
+	/*
+	 * flawfinder - path[] is zeroed before use and bounded with
+	 * snprintf(); its size is sufficient for all reasonable paths.
+	 */
 
 	depth++;
 	if (depth > 10)
@@ -1285,6 +1333,8 @@ static void recursively_delete(const char *dir, int depth)
 		return;
 	}
 
+	memset(path, 0, sizeof(path));
+
 	for (idx = 0; idx < namelist_length; idx++) {
 		struct stat sb;
 		if (strcmp(namelist[idx]->d_name, ".") == 0)
@@ -1292,6 +1342,7 @@ static void recursively_delete(const char *dir, int depth)
 		if (strcmp(namelist[idx]->d_name, "..") == 0)
 			continue;
 		snprintf(path, sizeof(path) - 1, "%s/%s", dir, namelist[idx]->d_name);
+		path[sizeof(path) - 1] = '\0';
 		if (lstat(path, &sb) != 0) {
 			error("%s: %s: %s", "lstat", path, strerror(errno));
 			continue;
@@ -1312,3 +1363,5 @@ static void recursively_delete(const char *dir, int depth)
 	debug("%s: %s", "removing", dir);
 	rmdir(dir);
 }
+
+/*@+mustfreefresh@ */
