@@ -1,7 +1,7 @@
 /*
  * Header for the watch functions program.
  *
- * Copyright 2025 Andrew Wood
+ * Copyright 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -22,10 +22,14 @@ struct watch_dir_params_s {
 	toplevel_path_t *toplevel_paths;
 	size_t toplevel_path_count;
 	const char *changedpath_dir;
+	const /*@null@ */ char *exchange_dir;
+	const /*@null@ */ char *exchange_identity;
+	const /*@null@ */ char *metrics_file;
 	unsigned long full_scan_interval;
 	unsigned long queue_run_interval;
 	unsigned long queue_run_max_seconds;
 	unsigned long changedpath_dump_interval;
+	unsigned long exchange_interval;
 	unsigned int max_dir_depth;
 	excluded_string_t excludes[MAX_EXCLUDES];
 	size_t exclude_count;
@@ -37,6 +41,10 @@ struct watch_dir_params_s {
 	bool no_file_tracking;
 };
 
+/*@-exportlocal@*/
 int watch_dir(struct watch_dir_params_s *);
 
+bool validate_exchange_identity(const char *);
+/*@+exportlocal@*/
+
 #endif				/* WATCH_H */
