@@ -1,7 +1,7 @@
 /*
  * Command-line interface to the watch_dir function provided in watch.c.
  *
- * Copyright 2014, 2021, 2023, 2025 Andrew Wood
+ * Copyright 2014, 2021, 2023, 2025-2026 Andrew Wood
  *
  * License GPLv3+: GNU GPL version 3 or later <https://gnu.org/licenses/gpl.html>.
  */
@@ -16,6 +16,7 @@
 #include <string.h>
 #include <errno.h>
 #include <getopt.h>
+#include <sys/utsname.h>
 
 /* List of command line arguments after options. */
 static
@@ -70,6 +71,18 @@ static void usage(void)
 		{ "-m", "--queue-run-max", N_("SEC"),
 		 N_("maximum time to spend processing the queue"),
 		 { 0, 0, 0, 0} },
+		{ "-x", "--exchange-dir", N_("DIR"),
+		 N_("use a directory to communicate with other instances"),
+		 { 0, 0, 0, 0} },
+		{ "-t", "--exchange-interval", N_("SEC"),
+		 N_("use the exchange directory every SEC seconds"),
+		 { 0, 0, 0, 0} },
+		{ "-I", "--identity", N_("NAME"),
+		 N_("override the name of this instance"),
+		 { 0, 0, 0, 0} },
+		{ "-M", "--metrics", N_("FILE"),
+		 N_("write metrics to a file"),
+		 { 0, 0, 0, 0} },
 		{ "", NULL, NULL, NULL, { 0, 0, 0, 0} },
 		{ "-h", "--help", NULL,
 		 N_("show this help and exit"),
@@ -164,12 +177,16 @@ static int parse_options(int argc, char **argv, struct watch_dir_params_s *param
 		{ "depth", 1, NULL, (int) 'r' },
 		{ "output-dir", 1, NULL, (int) 'o' },
 		{ "output", 1, NULL, (int) 'o' },
+		{ "exchange-dir", 1, NULL, (int) 'x' },
+		{ "exchange-interval", 1, NULL, (int) 't' },
+		{ "identity", 1, NULL, (int) 'I' },
+		{ "metrics", 1, NULL, (int) 'M' },
 		{ "debug", 0, NULL, (int) 'd' },
 		{ NULL, 0, NULL, 0 }
 	};
 	/*@+nullassign@ */
 	int option_index = 0;
-	char *short_options = "hVf:e:r:q:m:i:0aFDns:o:d";
+	char *short_options = "hVf:e:r:q:m:i:0aFDns:o:x:t:I:M:d";
 	char *copy;
 	int c;
 	unsigned long param;
@@ -285,11 +302,47 @@ static int parse_options(int argc, char **argv, struct watch_dir_params_s *param
 			}
 			params->changedpath_dir = copy;
 			break;
+		case 'x':
+			/*@-unrecog@ *//* splint doesn't know about realpath() */
+			copy = realpath(optarg, NULL);	/* flawfinder: ignore (see below) */
+			/*@+unrecog@ */
+			if (NULL == copy) {
+				fprintf(stderr, "%s: %s: %s\n", common_program_name, optarg, strerror(errno));
+				exit(EXIT_FAILURE);
+			}
+			if (NULL != params->exchange_dir) {
+				free((void *) (params->exchange_dir));
+			}
+			params->exchange_dir = copy;
+			break;
+		case 'I':
+			copy = xstrdup(optarg);
+			if (NULL == copy) {
+				return 1;
+			} else {
+				if (NULL != params->exchange_identity) {
+					free((void *) (params->exchange_identity));
+				}
+				params->exchange_identity = copy;
+			}
+			break;
+		case 'M':
+			copy = xstrdup(optarg);
+			if (NULL == copy) {
+				return 1;
+			} else {
+				if (NULL != params->metrics_file) {
+					free((void *) (params->metrics_file));
+				}
+				params->metrics_file = copy;
+			}
+			break;
 		case 'f':
 		case 'r':
 		case 'q':
 		case 'm':
 		case 'i':
+		case 't':
 			errno = 0;
 			param = strtoul(optarg, NULL, 10);
 			if (0 != errno) {
@@ -315,6 +368,9 @@ static int parse_options(int argc, char **argv, struct watch_dir_params_s *param
 			case 'i':
 				params->changedpath_dump_interval = param;
 				break;
+			case 't':
+				params->exchange_interval = param;
+				break;
 			}
 			break;
 		default:
@@ -360,6 +416,35 @@ static int parse_options(int argc, char **argv, struct watch_dir_params_s *param
 		return 1;
 	}
 
+	if ((NULL != params->exchange_dir) && (NULL == params->exchange_identity)) {
+		/*
+		 * If "-x" was used but "-I" was not, take the system
+		 * nodename as a default identity.
+		 */
+		struct utsname info;
+
+		memset(&info, 0, sizeof(info));
+		(void) uname(&info);
+
+		copy = xstrdup(info.nodename);
+		if (NULL == copy) {
+			return 1;
+		} else {
+			if (NULL != params->exchange_identity) {
+				/* for splint; this should optimise out. */
+				free((void *) (params->exchange_identity));
+			}
+			params->exchange_identity = copy;
+		}
+	}
+
+	if ((NULL != params->exchange_dir) && (NULL != params->exchange_identity)
+	    && !validate_exchange_identity(params->exchange_identity)) {
+		fprintf(stderr, "%s: %s: %s\n", common_program_name, params->exchange_identity,
+			_("not a valid exchange identity"));
+		return 1;
+	}
+
 	return 0;
 }
 
@@ -391,11 +476,12 @@ int main(int argc, char **argv)
 
 	memset(&params, 0, sizeof(params));
 
-	/* Set the defaults watch parameters. */
+	/* Set the default watch parameters. */
 	params.full_scan_interval = 7200;
 	params.queue_run_interval = 2;
 	params.queue_run_max_seconds = 5;
 	params.changedpath_dump_interval = 30;
+	params.exchange_interval = 1;
 	params.max_dir_depth = 20;
 	params.null_delimiter = false;
 	params.absolute_paths = false;
@@ -507,6 +593,14 @@ int main(int argc, char **argv)
 	free((void *) (params.changedpath_dir));
 	params.changedpath_dir = NULL;
 
+	free((void *) (params.exchange_dir));
+	params.exchange_dir = NULL;
+	free((void *) (params.exchange_identity));
+	params.exchange_identity = NULL;
+
+	free((void *) (params.metrics_file));
+	params.metrics_file = NULL;
+
 	for (eidx = 0; eidx < params.exclude_count; eidx++) {
 		if (NULL != params.excludes[eidx])
 			free(params.excludes[eidx]);
